import Vue from 'vue'
import axios from 'axios'
import store from '../store'
import {Message} from 'view-design'
// axios 配置
axios.defaults.timeout = 100000
// axios.defaults.baseURL = 'https://api.github.com';
Vue.prototype.Ajax = axios
// Add a request interceptor 请求
axios.interceptors.request.use(function (config) {
    config.params.index =  store.state.currentblade.currentIndex || 0
    config.headers = {Pragma: 'no-cache'}
    return config
}, function (error) {
    
    return Promise.reject(error)
})

// http response 拦截器 errorCode
axios.interceptors.response.use(
    response => {
        let data = response.data
        return data
    },
    err => {
        const status = err.response.status
        const data = err.response.data;
        switch (status) {
            case 401:
                // 未登录 清除已登录状态
                Cookies.set('userInfo', '');
                setStore('Authorization', '');
                Message.error("您没有权限做此操作，请联系管理员");
                break;
            case 403:
                // 没有权限
                Message.error("您没有权限做此操作，请联系管理员");
                break;
            case 404:
                // 没有权限
                Message.error("404,请联系管理员");
                break;
            case 500:
                // 错误
                if (data.msg !== null) {
                    Message.error(data.msg);
                } else {
                    Message.error("服务器异常，请联系管理员");
                }
                break;
        }
        // 返回状态码不为200时候的错误处理
        if(err.code == 'ECONNABORTED' && err.message.indexOf('timeout')!=-1){
            Message.error("请求超时，请刷新页面，再次尝试！");
            return Promise.reject(err);

        }
        return Promise.reject(err)
    }
)
export default {
    Get(url, params) {
       return axios.get(url, {params: params})
    },
    Post(url, params, fn) {
        return axios.post(url, params)
    },
    Delete(url, params, fn) {
        axios.delete( url, {params: params}).then(fn).catch(err => console.error(err))
    },
    uploadImg: '/file/upload_pic',    //上传图片接口
    uploadFile: '/file/upload_file',    //上传文件接口，不用登录的

    Down(url, name, type="application/pdf") {
        axios({
            method: 'get',
            url: URL + url,
            responseType: 'blob'
        }).then(data => {
            if (!data) return
            if (isIE) {
                var blob = new Blob([data], {type: type})
                if (window.navigator && window.navigator.msSaveOrOpenBlob) { // for IE
                    window.navigator.msSaveOrOpenBlob(blob, name)
                }
            } else {
                let url = window.URL.createObjectURL(new Blob([data]))
                let link = document.getElementById('download')
                link.href = url
                // link.target = "_blank"
                link.setAttribute('download', name)
                link.click()
            }
        }).catch(err => console.error(err))
    }
}

